#!/bin/sh

# %%%% TeXTallion %%%%
# Tiny almost-Kiss Word Processor
# http://anamnese.online.fr/site2/textallion/docs/presentation.html
# Complete source code: http://textallion.googlecode.com
# License: http://creativecommons.org/licenses/by-sa/3.0/

# initiate the variables, from the user's input


# make a pause. Resume by keypress.
pause(){
	echo ""
	echo "(PRESS A KEY TO CONTINUE)"
	echo ""
	read -s -n 1 -p "$*"
}

banner(){
	if [ `uname -o` = "Cygwin" ] ; then echo "" ; else clear
	fi
	echo -e "\n
 @---------------@                    
 / Le TeXtallion /                   
 @---------------@\n\n"
}

introduction(){
	if [ `uname -o` = "Cygwin" ] ; then echo "" ; else clear
	fi
	echo -e "\n
 @----------------------------------------@                    
 / Le TeXtallion, a simple word processor /                   
 @----------------------------------------@\n\n"
	echo "1: Create a new document"
	echo "2: Manipulate sources or Generate HTML, PDF, EPUB..."
	echo ""
	echo "3: More options and other tools (CYOA, updates...)"
	echo "4: Help"
	echo "0: Quit"
	echo ""
read ACTION

case $ACTION in
				create | new | "1")
					create_new_doc
					;;
				generate| manipulate | "2")
					choose_doc
					;;
				other|more|"3")
					manipulate_ter
					;;
				help|"4")
					help
					;;
				quit|"0")
					quit
					;;
				*)
					introduction
					;;
esac
}

help(){
	echo -e "This command-line interface is a replacement for the manipulation of a makefile. Please visit http://textallion.googlecode.com for more information about textallion."
	pause
	introduction
}

test_OS(){
if [ `uname -o` = "Cygwin" ]; then 
    OS=Win
    #export?
	TEXTALLIONPATH=C:/cygwin/usr/share/textallion/
	SUDO=
else
    OS=Unix
    #export?
	TEXTALLIONPATH=/usr/share/textallion/
	SUDO=sudo
fi
}

updatetextallion(){
if [ ! -d $TEXTALLIONPATH ]; then 
	echo "$TEXTALLIONPATH is not present on this system. We'll try to run the installer instead."
	pause
	installtextallion
else
	cd $TEXTALLIONPATH
	$SUDO hg pull
	$SUDO hg update  -C 
fi
}

installtextallion(){
if [ -e $TEXTALLIONPATH ]; then 
	echo "$TEXTALLIONPATH is already present on this system. We'll try to run the updater instead."
	pause
	updatetextallion
else
	echo "Textallion will be installed into $TEXTALLIONPATH: this folder will be created, then it will be synchronized with the development version, using Mercurial. Is it ok? (Y/n)"
		read choice
			case $choice in
					"n"|"N"|"no"|"NO"|"non")
						echo "Nothing was changed in your configuration"
						;;
					"y"|"Y"|"yes"|*)
					$SUDO mkdir -p $TEXTALLIONPATH/.hg
					echo "[paths]" | $SUDO tee -a $TEXTALLIONPATH/.hg/hgrc
					echo "default = https://textallion.googlecode.com/hg/" | sudo tee -a $TEXTALLIONPATH/.hg/hgrc	
					updatetextallion	
						;;
			esac
fi
}
	

quit(){
echo -e "\nGoodbye :)\n\n       http://textallion.googlecode.com  \n  "
exit
}

choose_doc(){
banner
if [ -e ~/textalliondocs ]; then 
	echo -e "Here are your already existing documents:\n  "
	#ls ~/textalliondocs/
	# scan only for folders, and remove cyoa games and the trailing slash
	ls -p ~/textalliondocs/ | grep "/" | sed 's@/@ @' | sed 's@cyoa-[a-z_-]*@@' | tr -d "\n"
	
	echo -e "\n\nWhich one do you select? (please type the full name)"
	echo ""
	read DOCUMENTNAME
	#export DOCUMENTNAME
		if [ -f ~/textalliondocs/$DOCUMENTNAME/$DOCUMENTNAME.t2t ]; then
			manipulate_doc
		else
			echo "This document is not existing, please choose another one or create a new one."
			pause
			introduction
		fi
else
	echo -e "It's probably the first time you're using textallion. We'll make you create a new document now. "
	pause
	create_new_doc
fi
}

manipulate_doc(){
	banner
	echo "1: Edit document $DOCUMENTNAME"
	echo ""
	echo "2: Generate HTML from $DOCUMENTNAME"
	echo "3: Generate PDF from $DOCUMENTNAME"
	echo "4: Generate EPUB from $DOCUMENTNAME"
	echo ""
	echo "5: read HTML from $DOCUMENTNAME"
	echo "6: read PDF from $DOCUMENTNAME"
	echo "7: read EPUB from $DOCUMENTNAME"
	echo ""
	echo "8: More options (index etc.)"
	echo ""
	echo "9: Choose another document to manipulate"
	echo ""
	echo "0: Previous menu"
	echo ""
	read ACTION
case $ACTION in
				edit | "1")
					cd ~/textalliondocs/$DOCUMENTNAME/
					make edit
					manipulate_doc
					;;
				html|"2")
					cd ~/textalliondocs/$DOCUMENTNAME
					make html
					pause
					manipulate_doc
					;;
				pdf|"3")
					cd ~/textalliondocs/$DOCUMENTNAME
					make pdf
					pause
					manipulate_doc
					;;
				epub|"4")
					cd ~/textalliondocs/$DOCUMENTNAME
					make epub
					pause
					manipulate_doc
					;;
				readhtml|"5")
					cd ~/textalliondocs/$DOCUMENTNAME
					make readhtml
					pause
					manipulate_doc
					;;
				read|"6")
					cd ~/textalliondocs/$DOCUMENTNAME
						if [ `uname -o` = "Cygwin" ] ; then echo "If SumatraPDF is not installed, please enter ~/textalliondocs/$DOCUMENTNAME and open the PDF from there." ; sumatrapdf $DOCUMENTNAME.pdf ; else make read
						fi
					pause
					manipulate_doc
					;;
				readepub|"7")
					cd ~/textalliondocs/$DOCUMENTNAME
					make readepub
					pause
					manipulate_doc
					;;
				more|"8")
					manipulate_bis
					;;
				another|"9")
					choose_doc
					;;
				previous|"0")
					introduction
					;;
				*)
					manipulate_doc
					;;	
esac
}


manipulate_bis(){
	banner
	echo ""
	echo "1: Generate HTML, PDF and EPUB, then create an html index to distribute your files on internet"
	echo "2: read HTML index of the distributed version of $DOCUMENTNAME"
	echo ""
	echo "3: Synchronize $DOCUMENTNAME makefile, LaTeX style and CSS style (need a diff tool, for Linux version)"
	echo ""	
	echo "4: Command-line interface to the document folder $DOCUMENTNAME (for using makefile for ex.)"
	echo ""
	echo "0: Previous menu"
	echo ""
	read ACTION
case $ACTION in
				all|"1")
					cd ~/textalliondocs/$DOCUMENTNAME
					make all
					pause
					manipulate_bis
					;;
				readindex|"2")
					cd ~/textalliondocs/$DOCUMENTNAME
					make readindex
					pause
					manipulate_bis
					;;				
				synchronize|"3")
					cd ~/textalliondocs/$DOCUMENTNAME
					make configuration-update
					pause
					manipulate_bis
					;;		
				cmd|"4")
					cd ~/textalliondocs/$DOCUMENTNAME/
					echo -e "(Type ctrl-d to exit once you have finished.)\n"
					bash -
					;;
				previous|"0")
					manipulate_doc
					;;		

				*)
					manipulate_bis
					;;	
esac
}

manipulate_ter(){
	banner
	echo ""
	echo "1: Create a new CYOA document"
	echo "2: Manipulate a CYOA document"
	echo ""
	echo "3: Try to install textallion on the system, if it's not already there"
	echo "4: Try to update textallion with the current devel version (need to be root on Linux)"
	echo ""
	echo "0: Previous menu"
	echo ""
	read ACTION
case $ACTION in
				cyoa|"1")
					create_new_cyoa
					pause
					manipulate_ter
					;;
				manipulate|"2")
					choose_cyoa
					pause
					manipulate_ter
					;;
				install|"3")
					installtextallion
					pause
					manipulate_ter
					;;
				update|"4")
					updatetextallion
					pause
					manipulate_ter
					;;
				previous|"0")
					introduction
					;;		
				*)
					manipulate_ter
					;;	
esac
}

create_new_doc(){
banner
echo -e "This script will initiate a new document. All requested data are mandatory, except for the tags and the language code.\n"

echo "What is the name of the document file (and folder) to be created? (Try to avoid accented letters, spaces and funky characters)"
read DOCUMENTNAME

echo "What is the title name of the document file to be created? "
read DOCUMENTTITLE

echo "Who is the author?"
read AUTHORNAME

echo "What are the tags defining this document (separated by commas)?"
read DOCTAGS

echo "What is the language code of the document (2 letters, i.e. 'en' for English)?"
read DOCLANG

# replace space by underscore for the output files, remove accented letters, lower case

DOCUMENTFOLDER=`echo ${DOCUMENTNAME} | sed 's/ /_/g' | sed 's/\x27/_/g' | sed 's/[êèéëÊÈÉË]/e/g' | sed 's/[îìíïÎÏ]/i/g' | sed 's/[áåàäâÀÂÄ]/a/g' | sed 's/[øôóòöÔÖ]/o/g' | sed 's/[üûùúÙÛÜ]/u/g' | sed y/ABCDEFGHIJKLMNOPQRSTUVWXYZçÿ/abcdefghijklmnopqrstuvwxyzcy/ `

# now test existing folder and finish the generation
export CYOASTATUS=
export CYOAINIT=
test_folder

# continue to the manipulation options
export DOCUMENTNAME=$DOCUMENTFOLDER
manipulate_doc
}



## CYOA



create_new_cyoa(){
banner
echo -e "This script will initiate a new CYOA game. All requested data are mandatory, except for the tags and the language code.\n"

echo "What is the name of the game file (and folder) to be created? (Try to avoid accented letters, spaces and funky characters). We'll add cyoa- to the title."
read DOCUMENTNAME

echo "What is the title name of the document file to be created? "
read DOCUMENTTITLE

echo "Who is the author?"
read AUTHORNAME

echo "What are the tags defining this document (separated by commas)?"
read DOCTAGS

echo "What is the language code of the document (2 letters, i.e. 'en' for English)?"
read DOCLANG

# replace space by underscore for the output files, remove accented letters, lower case

DOCUMENTFOLDER=cyoa-`echo ${DOCUMENTNAME} | sed 's/ /_/g' | sed 's/\x27/_/g' | sed 's/[êèéëÊÈÉË]/e/g' | sed 's/[îìíïÎÏ]/i/g' | sed 's/[áåàäâÀÂÄ]/a/g' | sed 's/[øôóòöÔÖ]/o/g' | sed 's/[üûùúÙÛÜ]/u/g' | sed y/ABCDEFGHIJKLMNOPQRSTUVWXYZçÿ/abcdefghijklmnopqrstuvwxyzcy/ `

# now test existing folder and finish the generation
# (now includeconf txt2tags.t2t will be included into the makefile)
#export CYOASTATUS="%!includeconf: /usr/share/textallion/core/txt2cyoa.t2t\n"
export CYOASTATUS=""
export CYOAINIT="== 0 ==\n\n- Start the game: 1\n\n\n== 1 ==\n\n\n"
test_cyoa_folder

# continue to the manipulation options
export DOCUMENTNAME=$DOCUMENTFOLDER
manipulate_cyoa
}

choose_cyoa(){
banner
if [ -e ~/textalliondocs ]; then 
	echo -e "Here are your already existing games:\n  "
	#ls ~/textalliondocs/
	# scan only for folders beginning by cyoa-, and remove the trailing slash
	ls -p ~/textalliondocs/ | grep "cyoa-" | sed 's@/@ @' | tr -d "\n"
	
	echo -e "\n\nWhich one do you select? (please type the full name, but you can omit the \"cyoa-\" part)"
	echo ""
	read DOCUMENTNAME
	#export DOCUMENTNAME
		if [ -f ~/textalliondocs/$DOCUMENTNAME/$DOCUMENTNAME.t2t ]; then
			manipulate_cyoa
	    elif [ -f ~/textalliondocs/cyoa-$DOCUMENTNAME/cyoa-$DOCUMENTNAME.t2t ]; then
			export DOCUMENTNAME=cyoa-$DOCUMENTNAME
			manipulate_cyoa	
		else
			echo "This game is not existing, please choose another one or create a new one."
			pause
			manipulate_ter
		fi
else
	echo -e "It's probably the first time you're using textallion. We'll make you create a new game now. "
	pause
	create_new_cyoa
fi
}

manipulate_cyoa(){
	banner
	echo "1: Edit game $DOCUMENTNAME"
	echo ""
	echo "2: Generate HTML from $DOCUMENTNAME"
	echo "3: Generate PDF from $DOCUMENTNAME"
	echo "4: Generate EPUB from $DOCUMENTNAME"
	echo ""
	echo "5: read HTML from $DOCUMENTNAME"
	echo "6: read PDF from $DOCUMENTNAME"
	echo "7: read EPUB from $DOCUMENTNAME"
	echo ""
	echo "8: More options (export to renpy, create graph etc)"
	echo ""
	echo "9: Choose another document to manipulate"
	echo ""
	echo "0: Previous menu"
	echo ""
	read ACTION
case $ACTION in
				edit | "1")
					cd ~/textalliondocs/$DOCUMENTNAME/
					make edit
					manipulate_cyoa
					;;
				html|"2")
					cd ~/textalliondocs/$DOCUMENTNAME
					make cyoa-html
					pause
					manipulate_cyoa
					;;
				pdf|"3")
					cd ~/textalliondocs/$DOCUMENTNAME
					make cyoa-pdf
					pause
					manipulate_cyoa
					;;
				epub|"4")
					cd ~/textalliondocs/$DOCUMENTNAME
					make cyoa-epub
					pause
					manipulate_cyoa
					;;
				readhtml|"5")
					cd ~/textalliondocs/$DOCUMENTNAME
					make readhtml
					pause
					manipulate_cyoa
					;;
				read|"6")
					cd ~/textalliondocs/$DOCUMENTNAME
						if [ `uname -o` = "Cygwin" ] ; then echo "If SumatraPDF is not installed, please enter ~/textalliondocs/$DOCUMENTNAME and open the PDF from there." ; sumatrapdf $DOCUMENTNAME.pdf ; else make read
						fi
					pause
					manipulate_cyoa
					;;
				readepub|"7")
					cd ~/textalliondocs/$DOCUMENTNAME
					make readepub
					pause
					manipulate_cyoa
					;;
				more|"8")
					manipulate_cyoa2
					;;
				another|"9")
					choose_cyoa
					;;
				previous|"0")
					manipulate_ter
					;;
				*)
					manipulate_cyoa
					;;	
esac
}


manipulate_cyoa2(){
	banner
	echo "1: Generate a graph of the nodes"
	echo ""
	echo "2: Export to Renpy format"
	echo "3: Export to Hyena format"
	echo "4: Export to Inform 7 format"
	echo ""
	echo "5: Command-line interface to the game folder $DOCUMENTNAME (for using makefile for ex.). "
	echo ""
	echo "0: Previous menu"
	echo ""
	read ACTION
case $ACTION in
				graph | "1")
					cd ~/textalliondocs/$DOCUMENTNAME
					make cyoa-graph
					pause
					manipulate_cyoa2
					;;
				renpy|"2")
					cd ~/textalliondocs/$DOCUMENTNAME
					make cyoa-renpy
					pause
					manipulate_cyoa2
					;;
				hyena|"3")
					cd ~/textalliondocs/$DOCUMENTNAME
					make cyoa-hyena
					pause
					manipulate_cyoa2
					;;
				inform7|"4")
					cd ~/textalliondocs/$DOCUMENTNAME
					make cyoa-inform7
					pause
					manipulate_cyoa2
					;;
				cmd|"5")
					cd ~/textalliondocs/$DOCUMENTNAME/
					echo -e "(Type ctrl-d to exit once you have finished.)\n"
					bash -
					;;
				previous|"0")
					manipulate_cyoa
					;;
				*)
					manipulate_cyoa2
					;;	
esac
}


	

## SETUP

setup(){
mkdir -p ~/textalliondocs/${DOCUMENTFOLDER}

cp /usr/share/textallion/samples/makefile ~/textalliondocs/${DOCUMENTFOLDER}
cp /usr/share/textallion/includes/sample.css ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.css
cp /usr/share/textallion/includes/sample.sty ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.sty

cp /usr/share/textallion/images/textallion_cover.svg ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.svg

cp /usr/share/textallion/images/sample_cover.png ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.png


sed -i -e "s@TEXTALLIONFOLDER = ../@TEXTALLIONFOLDER = /usr/share/textallion/@g" ~/textalliondocs/${DOCUMENTFOLDER}/makefile
sed -i -e "s@DOCUMENT = examples@DOCUMENT = ${DOCUMENTFOLDER}@g" ~/textalliondocs/${DOCUMENTFOLDER}/makefile
sed -i -e "s@xx DOCUMENT LANGUAGE xx@${DOCLANG}@g" ~/textalliondocs/${DOCUMENTFOLDER}/makefile
sed -i -e "s@xx DOCUMENT AUTHOR xx@${AUTHORNAME}@g" ~/textalliondocs/${DOCUMENTFOLDER}/makefile
sed -i -e "s@xx DOCUMENT TITLE xx@${DOCUMENTTITLE}@g" ~/textalliondocs/${DOCUMENTFOLDER}/makefile
sed -i -e "s@xx DOCUMENT TAGS xx@${DOCTAGS}@g" ~/textalliondocs/${DOCUMENTFOLDER}/makefile

# replace info in cover
sed -i -e "s@Author@${AUTHORNAME}@g"  ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.svg
sed -i -e "s@Le Textallion@${DOCUMENTTITLE}@g"  ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.svg


echo ${DOCUMENTTITLE} > ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t
echo ${AUTHORNAME}   >> ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t
echo -e "`date +%Y-%m-%d`\n\n"   >> ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t
echo -e "%% DEF DOCUMENT METADATA. Use your own. Remplace the second part only, don't modify the xx DOCUMENT ## xx \n"   >> ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t
echo -e "%!postproc(tex): 'xx DOCUMENT TITLE xx' '${DOCUMENTTITLE}'\n"   >> ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t
echo -e "%!postproc(tex): 'xx DOCUMENT AUTHOR xx' '${AUTHORNAME}'\n"   >> ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t
echo -e "%!postproc(tex): 'xx DOCUMENT TAGS xx' '${DOCTAGS}'\n\n"   >> ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t

echo -e "%!style(tex): ${DOCUMENTFOLDER}.sty\n" >> ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t
echo -e "%!style(xhtml): ${DOCUMENTFOLDER}.css\n\n" >> ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t
echo -e "%!includeconf: /usr/share/textallion/core/textallion.t2t\n" >> ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t
echo -e ${CYOASTATUS} >> ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t
echo -e "%!postproc(tex): 'TEXTALLIONPATH' '${TEXTALLIONPATH}'\n\n" >> ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t
echo -e ${CYOAINIT} >> ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t

echo "${DOCUMENTFOLDER} was created into the textalliondocs folder in your home. You can modify it from here and generate the target documents with this menu driven command line. (You can also enter this folder, edit ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.t2t with the text editor of your choice, and in order to generate the final documents, type \"make pdf\" or \"make html\" or \"make epub\"...)"
pause
}

test_folder(){
if [ -e ~/textalliondocs/${DOCUMENTFOLDER} ]; then 
	echo "This folder ~/${DOCUMENTFOLDER} is already present. Please choose another name or remove this folder, and run \"textallion\" again."
	pause
	create_new_doc
else
	setup
fi
}


test_cyoa_folder(){
if [ -e ~/textalliondocs/${DOCUMENTFOLDER} ]; then 
	echo "This folder ~/${DOCUMENTFOLDER} is already present. Please choose another name or remove this folder, and run \"textallion\" again."
	pause
	create_new_cyoa
else
	setup
	cp -fr /usr/share/textallion/includes/sample_cyoa.sty ~/textalliondocs/${DOCUMENTFOLDER}/${DOCUMENTFOLDER}.sty
fi
}

test_OS
introduction



